@@ -257,14 +257,13 @@ test_that("write_tif() errors correctly", {
   )
   expect_error(
     read_tif(system.file("img", "bad_ij2.tif", package = "ijtiff")),
-    paste(
-      " The ImageJ-written image you're trying to read",
-      "says it has 8 frames AND 5 slices. \n    * To be",
-      "read by the `ijtiff` package, the number of",
-      "slices OR the number of frames should be",
-      "specified in the TIFFTAG_DESCRIPTION (they're",
-      "interpreted as the same thing), but not both."
-    ),
+    paste(" The ImageJ-written image you're trying to read",
+          "says it has 8 frames AND 5 slices. \n    * To be",
+          "read by the `ijtiff` package, the number of",
+          "slices OR the number of frames should be",
+          "specified in the TIFFTAG_DESCRIPTION and they're",
+          "interpreted as the same thing. It does not make",
+          "sense for them to be different numbers."),
     fixed = TRUE
   )
 })
